@@ -9,23 +9,24 @@
 # Copyright © Semantyk 2020. All rights reserved.
 #############################################
 
+from semantyk.core.resource import Resource
 from semantyk.uuid_generator import generate_uuid
 from semantyk.namespace import RDFS, SMTK
 from rdflib import Literal, URIRef
 
-class Graph(object):
+class Graph(Resource):
     id:str
     triples:set
     uri:URIRef
 
-    def add(self, s, p:URIRef, o):
+    def add_triple(self, s, p:URIRef, o):
         self.triples.add((s,p,o))
 
-    def add(self, *triples:tuple):
+    def add_triples(self, *triples:tuple):
         for triple in triples:
             self.triples.add(triple)
         
-    def add(self, triples:set):
+    def add_triples(self, triples:set):
         for triple in triples:
             self.triples.add(triple)
 
@@ -157,16 +158,19 @@ class Graph(object):
                 triples.add((s,p,o.value))
         return Graph(self.id, triples = triples)
 
-    def remove(self, s = None, p:URIRef = None, o = None):
+    def remove_triple(self, s = None, p:URIRef = None, o = None):
         for _s,_p,_o in self.triples:
-            if s and not(p) and not(o):
+            if (not(s) and not(p) and not(o)) or \
+            (s and _s == s) or \
+            (p and _p == p) or \
+            (o and _o == o):
                 self.triples.remove((_s,_p,_o))
 
-    def remove(self, *triples:tuple):
+    def remove_triples(self, *triples:tuple):
         for triple in triples:
             self.triples.remove(triple)
 
-    def remove(self, triples:set):
+    def remove_triples(self, triples:set):
         for triple in triples:
             self.triples.remove(triple)
 
@@ -180,27 +184,30 @@ class Graph(object):
             dictionary[str(s)][str(p)].add(o)
         return dictionary
 
-    def update(self, new_triple:tuple, old_triple:tuple):
+    def update_triples(self, new_triple:tuple, old_triple:tuple):
         self.triples.remove(old_triple)
         self.triples.add(new_triple)
 
-    def __init__(self, id:str = None, triples:set = None, uri:URIRef = None):
-        self.id = id or generate_uuid()
+    def __eq__(self, other):
+        return super().__eq__(other) and self.triples == other.triples
+
+    def __init__(self, id:str = None, dictionary:dict = None, triples:set = None, uri:URIRef = None):
+        super().__init__(id, dictionary, uri=uri)
         self.triples = triples
-        self.uri = uri or URIRef(str(SMTK) + self.id)
 
     def __iter__(self):
         for triple in self.triples:
             yield triple
 
     def __str__(self):
-        result = str()
-        result += '\n' + str(self.uri) + ':'
-        triples = self.to_dict()
-        for s in triples:
-            result += '\n - ' + str(s) + ':'
-            for p in triples[s]:
-                result += '\n  - ' + str(p)
-                for o in triples[s][p]:
-                    result += '\n   - ' + str(o)
+        result = str(self.uri)
+        if self.triples:
+            result += ':'
+            triples = self.to_dict()
+            for s in triples:
+                result += '\n - ' + str(s) + ':'
+                for p in triples[s]:
+                    result += '\n  - ' + str(p)
+                    for o in triples[s][p]:
+                        result += '\n   - ' + str(o)
         return result
\ No newline at end of file
