@@ -10,16 +10,13 @@
 #############################################
 
 from semantyk.namespace.namespace import RDF, RDFS, SMTK
+from semantyk.uuid_generator import generate_uuid 
 from rdflib import Namespace, URIRef
 
 class Resource(object):
-    _uri:URIRef
-
-    def _get_uri(self):
-        return self._uri
-    def _set_uri(self, uri:URIRef):
-        self._uri = uri
-    uri = property(_get_uri, _set_uri)
+    dictionary:dict
+    id:str
+    uri:URIRef
 
     def _get_isDefinedBy(self):
         return self.get_values(str(RDFS.isDefinedBy))
@@ -34,8 +31,7 @@ class Resource(object):
     type = property(_get_type)
 
     def _get_properties(self):
-        for p in self.dictionary:
-            yield p
+        for p in self.dictionary: yield p
     properties = property(_get_properties)
 
     def _get_subClassOf(self):
@@ -46,43 +42,31 @@ class Resource(object):
         return self.get_values()
     values = property(_get_values)
 
-    def add_properties(self, *properties:str):
-        for p in properties:
-            if p not in self.dictionary:
-                self.dictionary[p] = set()
+    def add_property(self, p:str):
+        if p not in self.dictionary: self.dictionary[p] = set()
 
-    def add_values(self, p:str, *objects):
-        self.add_properties(p)
-        for o in objects:
-            self.dictionary[p].add(o)
+    def add_value(self, p:str, o):
+        self.add_property(p)
+        self.dictionary[p].add(o)
 
-    def delete_properties(self, *properties:str):
-        if not properties:
-            properties = self.dictionary
-        for p in properties:
-            if p in self.dictionary:
-                del self.dictionary[p]
+    def delete_property(self, p:str):
+        if p in self.dictionary: del self.dictionary[p]
 
-    def delete_values(self, p:str, *objects):
-        for o in objects:
-            if p in self.dictionary:
-                self.dictionary[p].remove(o)
+    def delete_value(self, p:str, o):
+        if p in self.dictionary: self.dictionary[p].remove(o)
 
     def from_triples(self, triples:set):
         dictionary = dict()
-        for (s,p,o) in triples:
-            if str(p) not in dictionary:
-                dictionary[str(p)] = set()
-            dictionary[str(p)].add(o)
+        if triples:
+            for s,p,o in triples:
+                if str(p) not in dictionary:
+                    dictionary[str(p)] = set()
+                dictionary[str(p)].add(o)
         return dictionary
             
-    def get_values(self, *properties:str):
-        if not properties:
-            properties = self.dictionary
-        for p in properties:
-            if p in self.dictionary:
-                for o in self.dictionary[p]:
-                    yield o
+    def get_values(self, p:str):
+        if p in self.dictionary: 
+            for o in self.dictionary[p]: yield o
 
     def to_triples(self):
         triples = set()
@@ -93,16 +77,16 @@ class Resource(object):
 
     def update_property(self, old_p:str, new_p:str):
         self.dictionary[new_p] = self.dictionary[old_p]
-        self.delete_properties(old_p)
+        self.delete_property(old_p)
 
-    def update_values(self, p:str, old_o, *new_objects):
-        self.delete_values(p, old_o)
-        self.add_values(p, new_objects)
+    def update_value(self, p:str, old_o, new_o):
+        self.delete_value(p, old_o)
+        self.add_value(p, new_o)
 
     def _generate_id(self, uri:URIRef = None):
         if uri and self.dictionary and str(RDFS.isDefinedBy) in self.dictionary:
             return str(uri).replace(list(self.dictionary[str(RDFS.isDefinedBy)])[0], '')
-        return super()._generate_id()
+        return generate_uuid()
 
     def _generate_uri(self, namespace:Namespace = None):
         result = URIRef((str(namespace or SMTK) + self.id or self._generate_id()))
@@ -111,10 +95,7 @@ class Resource(object):
         return result
 
     def __eq__(self, other):
-        return super().__eq__(other) and self.uri == other.uri
-
-    def __hash__(self):
-        return hash(self.uri)
+        return self.__class__ == other.__class__ and self.dictionary == other.dictionary and self.id == other.id and self.uri == other.uri
 
     def __init__(self, id:str = None, dictionary:dict = None, triples:set = None, uri:URIRef = None):
         self.dictionary = dictionary or self.from_triples(triples)
@@ -125,10 +106,13 @@ class Resource(object):
         return self.properties
 
     def __str__(self):
-        result = str()
-        result += '\n' + self.id + ':'
-        for p in self:
-            result += '\n - ' + str(p) + ':'
-            for o in self.dictionary[p]:
-                result += '\n  - ' + str(o)
+        result = self.id 
+        if self.dictionary:
+            result += ':'
+            for p in self.dictionary:
+                result += '\n - ' + str(p)
+                if self.dictionary[p]:
+                    result += ':'
+                    for o in self.dictionary[p]:
+                        result += '\n  - ' + str(o)
         return result
\ No newline at end of file
